from base64 import b64decode

from common.util.encrypt_util import encrypt_aes, decrypt_aes


class TestSqlUtil:
    def test_encrypt_aes(self):
        # 示例
        key = b'Sixteen byte key'
        plaintext = b'This is a secret message'

        # 加密
        ciphertext = encrypt_aes(key, plaintext)
        print(ciphertext)

        # 解密
        decrypted_text = decrypt_aes(key, b64decode(ciphertext))
        assert decrypted_text.decode() == 'This is a secret message'







import collections

from common.service.medical_text import extract_all_relation_key, extract_medical_text, sentence_count, \
    random_pick_relation_key
from common.util.database_connection_util import get_tumour_stage_connection


class TestSqlUtil:
    def test_extract_all_relation_key(self):
        pass
        # conn = get_tumour_stage_connection(b'my pleasure lord')
        # cursor = conn.cursor()
        # relation_key_list = extract_all_relation_key(cursor)
        # for relation_key in relation_key_list:
        #     print(relation_key)

    def test_extract_medical_text(self):
        conn = get_tumour_stage_connection(b'')
        cursor = conn.cursor()
        relation_key_list = extract_all_relation_key(cursor)[:1000]
        sentence_list = []
        for relation_key in relation_key_list:
            medical_text_list = extract_medical_text(cursor, relation_key)
            for medical_text in medical_text_list:
                sentence_list.extend(medical_text['文本列表'])
        sentence_count(sentence_list)

    def test_sentence_count(self):
        sentence_list = ["测试", "测试", "四大皆空", "第三方i哦", "第三方i哦", "第三方i哦"]
        sentence_count(sentence_list)

    def test_random_pick_relation_key(self):
        conn = get_tumour_stage_connection(b'')
        cursor = conn.cursor()
        all_relation_key_list = extract_all_relation_key(cursor)
        relation_key_dict = collections.defaultdict(list)
        for relation_key in all_relation_key_list:
            relation_key_dict[relation_key.medical_institution_code].append(relation_key)
        assert len(random_pick_relation_key(relation_key_dict, 500)) == 500
        assert len(random_pick_relation_key(relation_key_dict, 37)) == 37




from common.util.list_util import get_string_list_total_length


class TestListUtil:
    def test_get_string_list_total_length(self):
        l = get_string_list_total_length(['深爱着的', '人', '不会犯错'])
        assert l == 9



from common.util.string_util import any_match, any_match_bool, extract_digit, find_all, \
    remove_special_symbols, has_chinese, is_chinese, split_text, handle_short_sentence, locate_two_word


class TestStringUtil:
    def test_any_match(self):
        result = any_match("快乐池塘栽种了梦想就变成海洋", ["快乐", "梦想", "海洋", "人生", "纱布"])
        assert result == ["快乐", "梦想", "海洋"]

    def test_any_match_bool(self):
        result = any_match_bool("快乐池塘栽种了梦想就变成海洋", ["快乐", "人生", "纱布"])
        assert result is True

    def test_extract_digit(self):
        result = extract_digit("快乐1池塘栽5种了梦想就9变成海洋")
        assert result == "159"

    def test_find_all(self):
        positions = find_all("快了1池塘栽5种了梦想就9变成海洋", '了')
        assert positions == [1, 8]

    def test_remove_special_symbols(self):
        result = remove_special_symbols("快乐池塘\n\r\b栽\t种了梦想就变成海\n洋")
        assert result == "快乐池塘栽种了梦想就变成海洋"

    def test_has_chinese(self):
        result = has_chinese("dis当ogiosdg")
        assert result is True
        result = has_chinese("disogiosdg")
        assert result is False

    def test_is_chinese(self):
        result = is_chinese("好")
        assert result is True
        result = is_chinese("1")
        assert result is False
        result = is_chinese("a")
        assert result is False
        result = is_chinese("+")
        assert result is False

    def test_handle_short_sentence(self):
        result = handle_short_sentence([(0, 10), (11, 14), (15, 30), (31, 39)])
        assert result == [(0, 14), (15, 30), (31, 39)]

    def test_split_text(self):
        result = split_text("诊疗过程: 患儿入院后完善术前相关检查，排除手术禁忌后，患儿于2018-2-7行手术治疗，术后患儿入儿科重症 监护病房，病情稳定后患儿转入我科继续治疗，患儿术后恢复良好，无发热，无恶心呕吐。查体：神志清，精神欠佳，面色苍白，呼吸尚平稳，头皮术区纱布覆盖良好，干燥无渗出，头皮无肿胀，双瞳孔等大，直径2.5mm，对光反射灵敏，球结膜无水肿，颈软，双肺呼吸音粗，心律齐、无杂音，腹部平软，无反跳痛，无肌紧张,肝脾无肿大，肠鸣音正常,肛门及外生殖器外观无畸形，脊柱生理弯曲，四肢末梢温，毛细血管充盈征＜2秒，神经系统查体克氏征、布氏征及巴宾斯基征阴性，经上级医师查房决定预约今日出院。 术后病理回报显示:髓母细胞瘤、四级。 出院医嘱: 嘱患儿出院后1个月门诊复查，定期随诊。")
        assert result == ['诊疗过程:患儿入院后完善术前相关检查，排除手术禁忌后，患儿于2018-2-7行手术治疗，术后患儿入儿科重症监护病房，病情稳定后患儿转入我科继续治疗，患儿术后恢复良好，无发热，无恶心呕吐', '查体：神志清，精神欠佳，面色苍白，呼吸尚平稳，头皮术区纱布覆盖良好，干燥无渗出，头皮无肿胀，双瞳孔等大，直径2.5mm，对光反射灵敏，球结膜无水肿，颈软，双肺呼吸音粗，心律齐、无杂音，腹部平软，无反跳痛，无肌紧张,肝脾无肿大，肠鸣音正常,肛门及外生殖器外观无畸形，脊柱生理弯曲，四肢末梢温，毛细血管充盈征＜2秒，神经系统查体克氏征、布氏征及巴宾斯基征阴性，经上级医师查房决定预约今日出院', '术后病理回报显示:髓母细胞瘤、四级', '出院医嘱:嘱患儿出院后1个月门诊复查，定期随诊']

    def test_locate_two_word(self):
        assert locate_two_word("神经母细胞瘤神经的镂空设计符合4期神经母细胞瘤收到反馈就是刘佳分4期是快乐的感觉", "神经母细胞瘤", "4期") == (0, 15)
        assert locate_two_word("神经母细胞瘤神经的镂空设计符合4期神经母细胞瘤收到反馈就是刘佳分4期是快乐的感觉", "神经母细胞瘤", "4期", keep_order=False) == (17, 15)



import os
import zipfile
import rarfile


def unzip_files(directory):
    fail_list = []
    # 遍历目录中的所有文件和子目录
    for filename in os.listdir(directory):
        filepath = os.path.join(directory, filename)
        # 判断文件是否为RAR或ZIP格式
        if filename.endswith(".rar") or filename.endswith(".zip"):
            print(filename + "开始解压")
            # 创建解压缩目录
            extract_path = os.path.splitext(filepath)[0]
            os.makedirs(extract_path, exist_ok=True)
            # 解压缩文件
            if filename.endswith(".zip"):
                try:
                    with zipfile.ZipFile(filepath, 'r') as zip_ref:
                        zip_ref.extractall(extract_path)
                except Exception:
                    fail_list.append(filename)
            if filename.endswith(".rar"):
                try:
                    with rarfile.RarFile(filepath, 'r') as rar_ref:
                        rar_ref.extractall(extract_path)
                except Exception:
                    fail_list.append(filename)
            # 删除压缩文件
            print(filename + "解压成功")
        elif os.path.isdir(filepath):
            # 递归遍历子目录
            unzip_files(filepath)
    return fail_list




HOST_DICT = {
    "prod": "10.10.1.35",
    "prod_test": "172.23.198.22",
    "test": "172.23.198.14"
}

PASSWD_DICT = {
    "prod": b'zAIRNzFTFBqTT7RgZXqdIw==',
    "prod_test": b"BipPO6894MBVyng+M0h+XogEROrGPvi/whq8BxjURHQ=",
    "test": b'zAIRNzFTFBqTT7RgZXqdIw=='
}


STORE_BATCH_COUNT = 1000


from dataclasses import dataclass

from common.util.date_util import convert_standard_timestamp_to_compact


@dataclass
class RelationKey:
    medical_institution_code: str
    medical_record_no: str
    discharge_time: str

    def __repr__(self):
        return self.medical_institution_code + '|' + self.medical_record_no + '|' + convert_standard_timestamp_to_compact(self.discharge_time)

    def __eq__(self, other):
        return self.medical_institution_code == other.medical_institution_code and self.medical_record_no \
               == other.medical_record_no and self.discharge_time == other.discharge_time

    def __hash__(self):
        return hash((self.medical_institution_code, self.medical_record_no, self.discharge_time))


from common.util.date_util import convert_compact_timestamp_to_standard, convert_standard_timestamp_to_compact, \
    timestamp_parse, timeseg_parse, diff_between_dates


class TestDateUtil:
    def test_convert_compact_timestamp_to_standard(self):
        timestamp = convert_compact_timestamp_to_standard("20201202150001")
        assert timestamp == '2020-12-02 15:00:01'
        timestamp = convert_compact_timestamp_to_standard("0201202150001")
        assert timestamp is None
        timestamp = convert_compact_timestamp_to_standard("sdf20201202150001")
        assert timestamp is None

    def test_convert_standard_timestamp_to_compact(self):
        timestamp = convert_standard_timestamp_to_compact("2020-12-02 15:00:01")
        assert timestamp == '20201202150001'

    def test_timeseg_parse(self):
        assert timeseg_parse("两周三天", "20231231000000") == '2023-12-14'
        assert timeseg_parse("一年", "20231231000000") == '2022-12-31'

    def test_timestamp_parse(self):
        assert timestamp_parse("2023年02月03日") == '2023-02-03'
        assert timestamp_parse("2018-5月") == '2018-05'
        assert timestamp_parse("2020-07-271") == '2020-07-27'
        assert timestamp_parse("2009年") == '2009'
        assert timestamp_parse("2021.6.6") == '2021-06-06'
        assert timestamp_parse("2020-02-0918，30输血后疗效评估记录1.输血指征、诊断：急性髓系白血病(M1型)2.输血时间：2020年02月08日") == '2020-02-09'

    def test_diff_between_dates(self):
        assert diff_between_dates("2018-03-12 00:00:00", "2022-05-11 00:00:00") == '4-1-29'




